---
title: "OT"
author: "Jean Feydy"
institute: ""
topic: ""
theme: "metropolis"
colortheme:
fonttheme:
fontsize: 11pt
linkcolor: black
urlcolor: blue
linkstyle: bold
aspectratio: 169
titlegraphic: 
logo:
date:
section-titles: false
toc: false
---


## Who am I?

Background in **mathematics** and **data sciences**:

```{=latex}
\vspace*{-.25cm}
\begin{description}
\setlength\itemsep{-.5em}
\item[2012--2016] ENS Paris, mathematics.
\item[2014--2015] M2 mathematics, vision, learning at ENS Cachan.
\item[2016--2019] PhD thesis in \textcolor{red!80!black}{\textbf{medical imaging}} with Alain Trouvé at ENS Cachan.
\item[2019--2021] \textcolor{red!80!black}{\textbf{Geometric deep learning}} with Michael Bronstein at Imperial College.
\item[2021+] \textcolor{red!80!black}{\textbf{Medical data analysis}} in the HeKA INRIA team (Paris).
\end{description}
\vspace*{.4cm}
```


## HeKA : a translational research team for public health

`\begin{center}`{=latex}

![](images/HeKA.pdf){height=7cm}

`\end{center}`{=latex}



## My main motivation

Develop **robust and efficient** software that $\BR{stimulates}$ **other researchers**:

1. Speed up $\BR{geometric}$ **machine learning** on GPUs: \
   $\Longrightarrow~~$ **pyKeOps** library for distance and kernel matrices, 500k+ downloads.

2. Scale up $\BR{pharmacovigilance}$ to the full French population: \
   $\Longrightarrow~~$ **survivalGPU**, a fast re-implementation of the R survival package.

3. Ease access to modern statistical $\BR{shape analysis}$: \
   $\Longrightarrow~~$ **GeomLoss**, truly scalable optimal transport in Python. \
   $\Longrightarrow~~$ **scikit-shapes**, to be released soon.


## Today’s talk -- assuming that you would enjoy some applied maths

1. The **optimal transport** problem. \

2. Efficient discrete **solvers**. \

3. **Applications** and **open** problems. \


# Optimal transport?

## Optimal transport (OT) generalizes sorting to spaces of dimension D $>$ 1



::: columns

:::: {.column width=70%}

`\vspace*{.3cm}`{=latex}

If $\a{\text{A} = (\text{x}_\text{1}, \dots, \text{x}_\text{N})}$  and  $\b{\text{B} = (\text{y}_\text{1}, \dots, \text{y}_\text{N})}$ \
are two clouds of N points in $\mathbb{R}^\text{D}$,
we define:


```{=latex}
\vspace*{-.3cm}
\begin{equation*}
\OT(\a{\text{A}},\b{\text{B}}) ~=~ \min_{\sigma \in \mathcal{S}_\text{N}}~ \frac{\text{1}}{\text{2N}} \sum_{\text{i\,=1}}^\text{N} \v{\|~\a{\text{x}_i} - \b{\text{y}_{\sigma(i)}}\|^2}
\end{equation*}
\vspace*{.2cm}
```

Generalizes **sorting** to metric spaces. \
**Linear problem** on the permutation matrix $\g{\text{P}}$:

```{=latex}
\begin{equation*}
\OT(\a{\text{A}},\b{\text{B}}) ~=~ \min_{\g{\text{P}} \in \mathbb{R}^{\text{N}\times \text{N}} ~}
\frac{\text{1}}{\text{2N}} \sum_{\text{i, j\,=1}}^{\text{N}} \g{\text{P}_{i,j}} \cdot \v{ \|~ \a{\text{x}_i} - \b{\text{y}_j} \|^2 }~,
\end{equation*}
\vspace*{-.6cm}
\begin{align*}
&\text{s.t.} &
\g{ \text{P}_{i,j}} ~&\geqslant ~\text{0} &
\underbrace{\b{\textstyle\sum_j} \g{ \text{P}_{i,j}} ~=~ \a{\text{1}}}_{\text{Each source point\dots{}}}& &
\underbrace{\vphantom{\textstyle\sum_j}\a{\textstyle\sum_i} \g{ \text{P}_{i,j}} ~=~ \b{\text{1}}~.}_{\text{is transported onto the target.}}
\end{align*}

```

::::

:::: {.column width=25%}

```{=latex}
\begin{center}
	\begin{tikzpicture}[scale=.5,x=.7cm,y=-.7cm]
		%\node[anchor = east] at (0,4) {source};
		\draw[->,>=latex,thick,color=black]  (0,0)--(0,16.5);
		\node[circle,fill=red!80!black,inner sep=0pt,minimum size=7pt,label=left:{$\a{\text{x}_\text{1}}$}] (x1) at (0,1) {};
		\node[circle,fill=red!80!black,inner sep=0pt,minimum size=7pt,label=left:{$\a{\text{x}_\text{2}}$}] (x2) at (0,2) {};
		\node[circle,fill=red!80!black,inner sep=0pt,minimum size=7pt,label=left:{$\a{\text{x}_\text{3}}$}] (x3) at (0,3.5) {};
		\node[circle,fill=red!80!black,inner sep=0pt,minimum size=7pt,label=left:{$\a{\text{x}_\text{4}}$}] (x4) at (0,5) {};
		\node[circle,fill=red!80!black,inner sep=0pt,minimum size=7pt,label=left:{$\a{\text{x}_\text{5}}$}] (x5) at (0,7.5) {};


		%\node[anchor = east] at (0,0) {cible};
		\draw[->,>=latex,thick,color=black]  (4,0)--(4,16.5);
		\node[circle,fill=blue,inner sep=0pt,minimum size=7pt,label=right:{$\b{\text{y}_\text{3}}$}] (y1) at (4,5.5) {};
		\node[circle,fill=blue,inner sep=0pt,minimum size=7pt,label=right:{$\b{\text{y}_\text{5}}$}] (y2) at (4,7) {};
		\node[circle,fill=blue,inner sep=0pt,minimum size=7pt,label=right:{$\b{\text{y}_\text{2}}$}] (y3) at (4,8.5) {};
		\node[circle,fill=blue,inner sep=0pt,minimum size=7pt,label=right:{$\b{\text{y}_\text{4}}$}] (y4) at (4,12.5) {};
		\node[circle,fill=blue,inner sep=0pt,minimum size=7pt,label=right:{$\b{\text{y}_\text{1}}$}] (y5) at (4,15) {};

		\node[anchor = north, align=center, color=otplan!70!black] at (2,17) {{assignment}\\ ${\sigma:\zp[i]{1,5}\rightarrow \zp[i]{1,5}}$};

		\draw[color=otplan,very thick] (x1) -- (y1) (x2) -- (y2) (x3) -- (y3) (x4) -- (y4) (x5) -- (y5);

		%\onslide<2,3,4,6->{\draw[color=green!80!black,thick] (x3) -- (y3) (x4) -- (y4);}
		%\onslide<5>{\draw[color=green!80!black] (x4) -- (y3);
		%\draw[color=green!80!black, very thick] (x3) -- (y4);}

	\end{tikzpicture}
	\end{center}
```

::::

:::

## Practical use

Alternatively, we understand OT as:

- Nearest neighbor **projection** + **incompressibility** constraint. \

- Fundamental example of **linear optimization** over the transport plan $\g{ \text{P}_{i,j}}$.

\
This theory induces two main quantities:

- The transport plan $\g{ \text{P}_{i,j}}$ $\simeq$ the optimal mapping $\a{x_i} \mapsto \b{y_{\sigma(i)}}$. \

- The "Wasserstein" distance $\sqrt{\OT(\a{\text{A}},\b{\text{B}})}$.

```{=latex}


\end{frame}



\begin{frame}{The optimal transport plan}
	\vspace*{1cm}

	\centerline{
	\begin{tabular}{ccc}
	\includegraphics<1>[height=6cm]{images/registration_2D/densities/000.png}%
	\includegraphics<2>[height=6cm]{images/registration_2D/crescents/000.png}%
	\includegraphics<3>[height=6cm]{images/registration_2D/worms/000.png}%
	\includegraphics<4>[height=6cm]{images/registration_2D/moons/000.png}%
	&\qquad&
	\includegraphics<1>[height=6cm]{images/registration_2D/densities/010.png}%
	\includegraphics<2>[height=6cm]{images/registration_2D/crescents/010.png}%
	\includegraphics<3>[height=6cm]{images/registration_2D/worms/010.png}%
	\includegraphics<4>[height=6cm]{images/registration_2D/moons/010.png}%
	\\
	Before
	&&
	After
	\end{tabular}
	}

```


## OT induces a geometry-aware distance between probability distributions `\cite{peyre}`{=latex}

**Gauss** map    $\mathcal{N} : (m, \sigma) \in \mathbb{R}\times\mathbb{R}_{\geqslant 0}~~~\mapsto~~~\mathcal{N}(m, \sigma) \in \mathbb{P}(\mathbb{R})$.

If the space of **probability distributions** $\mathbb{P}(\mathbb{R})$ is endowed with a given metric, \
what is the "pull-back" geometry on the space of **parameters** $(m, \sigma)$?

::: columns

:::: {.column width=55%}

`\begin{center}`{=latex}

![](images/wasserstein/Gaussian_fisher_rao.png){height=45%}

Fisher-Rao ($\simeq$ relative entropy) on $\mathcal{N}(m, \sigma)$ \
$\rightarrow$ Hyperbolic **Poincaré** metric on $(m, \sigma)$.

`\end{center}`{=latex}

::::

:::: {.column width=40%}

`\begin{center}`{=latex}

![](images/wasserstein/Gaussian_wasserstein.png){height=45%}

OT on $\mathcal{N}(m, \sigma)$ \
$\rightarrow$ Flat **Euclidean** metric on $(m, \sigma)$.

`\end{center}`{=latex}

::::

:::



# How should we solve the OT problem?


## Duality: central planning with $\text{N}\text{M}$ variables $\simeq$ outsourcing with $\text{N}+\text{M}$ variables

```{=latex}

	\hspace*{.5cm}
	%
	\begin{minipage}{\linewidth}
	\vspace{-.5cm}
	\hspace*{.5cm}
	\begin{align*}
		\OT(\a{\al},\b{\be})~&=~
		\min_{\g{\pi}} ~\langle \,\g{\pi}\,,\, \v{  \C}\, \rangle , ~~\text{with $\v{ \C(\a{x_i},\b{y_j}) ~=~ \tfrac{1}{p}\|\a{x_i} - \b{y_j}\|^p }$}
		& \longrightarrow~~&\text{Assignment}\\
		&\qquad\text{s.t.}~~ \g{\pi}~\geqslant~0, ~\quad
		\g{\pi} \,\textbf{\b{1}}~=~ \a{\al}, ~\quad
		\t{\g{\pi}} \textbf{\a{1}}~=~ \b{\be}
	\end{align*} 

	\hspace*{-1cm}\vspace{1.5cm}
	\begin{tabular}{m{.2\linewidth}@{\qquad\qquad}m{.45\linewidth}m{.2\linewidth}}
		\begin{tabular}{cc}
			\includegraphics[height=2.5cm]{images/intuitions/zhukov.jpg} \\
			$\sum_{i,j} \g{\pi_{i,j}} \, \v{ \C(\a{x_i},\b{y_j}) }$
		\end{tabular}
		&
		\only<1>{\includegraphics[width=\linewidth]{images/intuitions/wireframe_1.png}}%
		%\only<3>{\includegraphics[width=\linewidth]{images/intuitions/prices_none.png}}%
		%\only<4>{\includegraphics[width=\linewidth]{images/intuitions/prices_f.png}}%
		\onslide<2->{\includegraphics[width=\linewidth]{images/intuitions/prices.png}}
		& 
		\begin{tabular}{cc}
			\onslide<2->{ \includegraphics[height=2.5cm]{images/intuitions/postman.png} } \\
			\onslide<2->{ $\a{ \sum_{i} \al_i f_i } + \b{ \sum_j \be_j g_j }$ }
		\end{tabular}
	\end{tabular}
	
	\vspace{-2cm}
	\onslide<2->{
	\begin{align*}
		\phantom{\OT(\a{\al},\b{\be})~}
		&\onslide<3->{\mathbf{=}}~ \max_{\a{f}\,,\, \b{g}}~ \qquad \langle \,\a{\al}\,,\, \a{f}\,\rangle 
		~+~\langle\,\b{\be}\,,\, \b{g}\, \rangle 
		& \longrightarrow~~&\text{FedEx} \\
		&\qquad\text{s.t.}~~\qquad \a{f(x_i)}\,+\,\b{g(y_j)}~\leqslant~ \v{  \C(\a{x_i}, \b{y_j}) } , \qquad
	\end{align*}
	}
	\end{minipage}

\end{frame}

\begin{frame}{Being too greedy... doesn't work!}
```

`\vspace*{.5cm}\begin{center}`{=latex}

![](images/dual_optimization/algorithm_31.png){height=100%}

`\end{center}`{=latex}


## The auction algorithm: take it easy with a slackness $~\varepsilon > 0$

`\vspace*{.5cm}\begin{center}`{=latex}

![](images/dual_optimization/algorithm_32.png){height=100%}

`\end{center}`{=latex}


## The Sinkhorn algorithm: use a softmin, get a well-defined optimum

`\vspace*{.5cm}\begin{center}`{=latex}

![](images/dual_optimization/algorithm_33.png){height=100%}

`\end{center}`{=latex}


## The symmetric Sinkhorn algorithm: stay close to the diagonal if $\text{A}\simeq \text{B}$

`\vspace*{.5cm}\begin{center}`{=latex}

![](images/dual_optimization/algorithm_sym.png){height=100%}

`\end{center}`{=latex}


## Remark 1: a streamlined algorithm

One key operation -- the soft, $\BR{weighted distance transform}$:
$$\a{\forall i \in [1, \text{N}]}, ~~ \a{f(x_i)} \gets \min_{\b{y\sim \beta}} \big[ \v{\C(\a{x_i}, \b{y})} - \b{g(y)} \big]
= -\varepsilon \log \b{\sum_{j=1}^\text{M} \beta_j} \exp \tfrac{1}{\varepsilon} \big[ \b{g_j} - \v{\C(\a{x_i}, \b{y_j})}\big]~.
$$

Similar to the chamfer distance transform, convolution with a Gaussian kernel... \
Fast implementations with **pyKeOps**:

- If $\v{\C(\a{x_i}, \b{y_j})}$ is a closed formula: **bruteforce** scales to $\text{N}, \text{M} \simeq \text{100k}$ in 10ms on a GPU.
  
- If $\a{\text{A}}$ and $\b{\text{B}}$ have a low-dimensional support: \
  use a clustering and **truncation** strategy to get a x10 speed-up.

- If $\a{\text{A}}$ and $\b{\text{B}}$ are supported on a 2D or 3D grid and $\v{\C(\a{x_i}, \b{y_j}) = \tfrac{1}{2}\|\a{x_i} - \b{y_j}\|^2}$: \
  use a **separable** distance transform to get a second x10 speed-up. \
  (N.B.: FFTs run into numerical accuracy issues.)

## Remark 2: annealing works!

The **Auction/Sinkhorn** algorithms:

- Improve the dual cost by at least $~\varepsilon$ at each (early) step.
- Reach an $\varepsilon$-optimal solution with $(\max \C) ~/~ \varepsilon~$ steps.

Simple heuristic: run the optimization with $\BR{decreasing values}$ of $\varepsilon$.

`\begin{center}`{=latex}

$\varepsilon$-scaling \
$~~~ = ~~~$ **simulated annealing** \
$~~~ = ~~~$ **multiscale** strategy \
$~~~ = ~~~$ **divide and conquer**

`\end{center}`{=latex}



## Remark 3: the curse of dimensionality



::: columns


:::: {.column width=50%}

`\begin{center}`{=latex}

![](images/dual_optimization/peaky.pdf){height=45%}

`\end{center}`{=latex}

In **low dimension**:

- $\|x-y\|$ takes large and small values.
- The OT objective is $\BR{peaky}$ wrt. $\pi$.
- $\varepsilon$-optimal solutions are **useful**. 
- $\text{OT}(\text{discrete samples}) \simeq \text{OT}(\text{underlying distributions})$

::::

:::: {.column width=50%}

`\begin{center}`{=latex}

![](images/dual_optimization/flat.pdf){height=45%}

`\end{center}`{=latex}

In **high dimension**:

- $\|x-y\|$ gets closer to a constant.
- The OT objective is $\BR{flat}$ wrt. $\pi$.
- $\varepsilon$-optimal solutions are **random**. 
- $\text{OT}(\text{discrete samples}) \neq \text{OT}(\text{underlying distributions})$

::::

:::


## To recap 80+ years of work...

Key dates for discrete optimal transport with N points:

- `\cite{kantorovich1942translocation}`{=latex}: `\defi{Dual}`{=latex} problem of Kantorovitch.
- `\cite{kuhn1955hungarian}`{=latex}: `\defi{Hungarian}`{=latex} methods in $O(\text{N}^3)$.
- `\cite{bertsekas79auction}`{=latex}: **Auction** algorithm in $O(\text{N}^2)$.
- `\cite{kosowsky1994invisible}`{=latex}: **SoftAssign** = Sinkhorn + simulated annealing, in $O(\text{N}^2)$.
- `\cite{gold1998new,TPSRPM}`{=latex}: **Robust Point Matching** = Sinkhorn as a loss.
- `\cite{CuturiSinkhorn}`{=latex}: Start of the `\contexte{GPU era.}`{=latex}
- `\cite{merigot2011multiscale,levy2015numerical,schmitzer2019stabilized}`{=latex}: **multi-scale** solvers in $O(\text{N}\log \text{N})$. \
  $~$
- `\solution{Solution,}`{=latex}today: **Multiscale Sinkhorn algorithm, on the GPU**.


`\begin{center}`{=latex}
$\Longrightarrow$ Generalized `\solution{QuickSort}`{=latex}algorithm.
`\end{center}`{=latex}


```{=latex}
\end{frame}

\begin{frame}{Visualizing $F$, $G$ and the Brenier map $\nabla F(x_i) = -\tfrac{1}{\alpha_i}\partial_{x_i} \OT(\alpha,\beta)$}
	\vspace{.3cm}
\begin{center}
	\includegraphics[height=.8\textheight]{images/truncation/it_08.png}%
\end{center}

\vspace{-.5cm}
\hspace*{5.8cm}
OT plan in 2D.
\end{frame}


\begin{frame}{Visualizing $F$, $G$ and the Brenier map $\nabla F(x_i) = -\tfrac{1}{\alpha_i}\partial_{x_i} \OT(\alpha,\beta)$}
	\vspace{.3cm}
\begin{center}
	\includegraphics<1>[height=.8\textheight]{images/scaling/it_01.png}%
	\includegraphics<2>[height=.8\textheight]{images/scaling/it_02.png}%
	\includegraphics<3>[height=.8\textheight]{images/scaling/it_03.png}%
	\includegraphics<4>[height=.8\textheight]{images/scaling/it_04.png}%
	\includegraphics<5>[height=.8\textheight]{images/scaling/it_05.png}%
	\includegraphics<6>[height=.8\textheight]{images/scaling/it_06.png}%
	\includegraphics<7>[height=.8\textheight]{images/scaling/it_07.png}%
	\includegraphics<8>[height=.8\textheight]{images/scaling/it_08.png}%
\end{center}

\vspace{-.5cm}
\hspace*{5.2cm}
Iteration %
\only<1>{0}%
\only<2>{1}%
\only<3>{2}%
\only<4>{3}%
\only<5>{4}%
\only<6>{5}%
\only<7>{6}%
\only<8>{7}%
, blur $\sigma$ = $\sqrt{\varepsilon}$ = %
\only<1>{$2^0$}%
\only<2>{$2^{-1}$}%
\only<3>{$2^{-2}$}%
\only<4>{$2^{-3}$}%
\only<5>{$2^{-4}$}%
\only<6>{$2^{-5}$}%
\only<7>{$2^{-6}$}%
\only<8>{\texttt{.01}}%
\end{frame}



\begin{frame}{Visualizing $F$, $G$ and the Brenier map $\nabla F(x_i) = -\tfrac{1}{\alpha_i}\partial_{x_i} \OT(\alpha,\beta)$}
	\vspace{.3cm}
\begin{center}
	\includegraphics<1>[height=.8\textheight]{images/truncation/it_01.png}%
	\includegraphics<2>[height=.8\textheight]{images/truncation/it_02.png}%
	\includegraphics<3>[height=.8\textheight]{images/truncation/it_03.png}%
	\includegraphics<4>[height=.8\textheight]{images/truncation/it_04.png}%
	\includegraphics<5>[height=.8\textheight]{images/truncation/it_05.png}%
	\includegraphics<6>[height=.8\textheight]{images/truncation/it_06.png}%
	\includegraphics<7>[height=.8\textheight]{images/truncation/it_07.png}%
	\includegraphics<8>[height=.8\textheight]{images/truncation/it_08.png}%
\end{center}

\vspace{-.5cm}
\hspace*{5.2cm}
Iteration %
\only<1>{0}%
\only<2>{1}%
\only<3>{2}%
\only<4>{3}%
\only<5>{4}%
\only<6>{5}%
\only<7>{6}%
\only<8>{7}%
, blur $\sigma$ = %
\only<1>{$2^0$}%
\only<2>{$2^{-1}$}%
\only<3>{$2^{-2}$}%
\only<4>{$2^{-3}$}%
\only<5>{$2^{-4}$}%
\only<6>{$2^{-5}$}%
\only<7>{$2^{-6}$}%
\only<8>{\texttt{.01}}%


```


## Scaling up optimal transport to anatomical data

```{=latex}

\begin{center} 
	Progresses of the last decade add up to a 
	$\times \textbf{100}$ - $\times \textbf{1000}$ acceleration:
	
	Sinkhorn GPU
	$\xrightarrow{\times \text{10}}$
	+ KeOps
	$\xrightarrow{\times \text{10}}$
	+ Annealing
	$\xrightarrow{\times \text{10}}$
	+ Multi-scale
	
	
	With a precision of 1\%, on a modern gaming GPU:\\~
	\end{center}

	\vspace*{-.25cm}
	\begin{tabular}{cccc}
	\begin{minipage}{.2\linewidth}
	\begin{center}
	~\\
	\texttt{pip install geomloss}\\
	+\\
	modern GPU\\ (1 000 €)
	\end{center}
	\end{minipage}
	&
	\begin{minipage}{.1\linewidth}
	~\\
	$\Longrightarrow$
	\end{minipage}
	&
	\begin{minipage}{.3\linewidth}
	\includegraphics[height=3.5cm]{images/dragon_ball/lowres.png}
	\end{minipage}
	&
	\begin{minipage}{.3\linewidth}
	\includegraphics[height=3.5cm]{images/dragon_ball/highres.png}
	\end{minipage}
	\\
	&&
	10k points in 30-50ms
	&
	\textbf{100k points in 100-200ms}
	\end{tabular}
```


# Applications


## A typical example in anatomy: lung registration "Exhale -- Inhale"

`\begin{center}`{=latex}

![](images/applications/poumons.png){height=85%}

`\end{center}\vspace*{-.3cm}`{=latex}

**Complex** deformations, high **resolution** (50k--300k points), high **accuracy** ($<$ 1mm).



## State-of-the-art networks -- and their limitations

::: columns

:::: {.column width=45%}

`\begin{center}`{=latex}
`\vspace*{1cm}`{=latex}

![](images/architectures/deep_reg_module.pdf){width=\textwidth}

`\vspace*{.25cm}`{=latex}
**Multi-scale** convolutional \
point neural network.

`\end{center}`{=latex}


::::

:::: {.column width=50%}

`\vspace*{.6cm}`{=latex}
Point neural nets, **in practice**:

- Compute **descriptors** at all scales.
- **Match** them using geometric layers.
- Train on **synthetic** deformations.

\
Strengths and weaknesses:

- Good at **pairing** branches.
- Hard to train to high **accuracy**.

\
$\Longrightarrow$    **Complementary** to OT.

::::


:::




## Three-steps registration

`\begin{center}\vspace*{.2cm}`{=latex}

![](images/drobot/drobot_summary.pdf){width=80%}

`\end{center}\vspace*{-.5cm}`{=latex}

 \
This **pragmatic** method:

- Is **easy to train** on synthetic data.
- Scales up to high-resolution: 100k points in 1s.
- Excellent results: **KITTI** (outdoors scans) and **DirLab** (lungs).

`\begin{center}`{=latex}
***Accurate*** *point cloud registration with **robust** optimal transport*,\
Shen, Feydy et al., NeurIPS 2021.
`\end{center}`{=latex}

## Three-steps registration


`\begin{center}`{=latex}

![](images/applications/lung_registration/full.png){height=85%}

`\end{center}\vspace*{-.3cm}`{=latex}




## Wasserstein barycenters `\cite{agueh_2011}`{=latex}

```{=latex}
\vspace*{-.5cm}
\begin{align*}
	\text{Barycenter}~~\a{\al^*}
	~=~\arg \min_{\a{\al}} 
	\sum_{i=1}^4 \,\lambda_i\,\text{Loss}(\,\a{\al}\,,\, \b{\be_i}\,)~.
\end{align*}
```

::: columns

:::: {.column width=45%}

`\begin{center}`{=latex}

![](images/wasserstein/linear_barycenters.png){height=60%}

**Euclidean** barycenters. \
$\text{Loss}(\a{\al},\b{\be}) = \|\a{\al}-\b{\be}\|^2_{L^2}$

`\end{center}`{=latex}

::::

:::: {.column width=45%}

`\begin{center}`{=latex}

![](images/wasserstein/wasserstein_barycenters.png){height=60%}

**Wasserstein** barycenters. \
$\text{Loss}(\a{\al},\b{\be}) = \OT(\a{\al},\b{\be})$

`\end{center}`{=latex}

::::

:::


## Wasserstein barycenters

From a computational perspective:

- The problem is **convex** (easy) wrt. the weights.
- The support of the barycenter lies in the **convex hull** of the input distributions.

The $\BR{curse of dimensionality}$ hits hard:

- In high dimension, identifying the support can become **NP-hard**.
- In dimensions 2 and 3, we can just use a grid and recover **super fast** algorithms.
  Computing OT distances and barycenters between $\BR{density maps}$ is a solved problem.


`\begin{center}`{=latex}

$\Longrightarrow$ We can now **easily** do manifold learning with e.g. UMAP \
in Wasserstein spaces of **2D and 3D** distributions.

`\end{center}`{=latex}

## An example this afternoon: Anna Song's presentation on 3D shape textures


`\begin{center}`{=latex}

![](images/umap.png){height=90%}

`\end{center}`{=latex}



# Conclusion

## Genuine team work

```{=latex}
\vspace*{1cm}

\centerline{
\begin{tabular}{ccccc}
\includegraphics[height=2cm]{images/sourires/medaillons/Benjamin_2.png}
&
\includegraphics[height=2cm]{images/sourires/medaillons/Joan_2.png}
&
\includegraphics[height=2cm]{images/sourires/medaillons/Thibault_2.png}
&
\includegraphics[height=2cm]{images/sourires/medaillons/FX_2.png}
&
\includegraphics[height=2cm]{images/sourires/medaillons/Gabriel_2.png}
\\
\textcolor{blue!100!black}{Benjamin Charlier}
&
\textcolor{blue!100!black}{Joan Glaunès}
&
\textcolor{red!65!black}{Thibault Séjourné}
&
\textcolor{red!65!black}{~~~F.-X. Vialard~~~}
&
\textcolor{red!65!black}{~~~Gabriel Peyré~~~}
\\[.5cm]
\includegraphics[height=2cm]{images/sourires/medaillons/Alain_2.png}
&
\includegraphics[height=2cm]{images/sourires/medaillons/Marc.png}
&
\includegraphics[height=2cm]{images/sourires/medaillons/Zhengyang.png}
&
\includegraphics[height=2cm]{images/sourires/medaillons/olga.png}
&
\includegraphics[height=2cm]{images/sourires/medaillons/hieu.png}\\
Alain Trouvé
&
\textcolor{green!60!black}{Marc Niethammer}
&
\textcolor{green!60!black}{Shen Zhengyang}
&
\textcolor{black!60!black}{Olga Mula}
&
\textcolor{black!60!black}{Hieu Do}\\[.5cm]
\end{tabular}
}

```


## Key points

- Optimal Transport = `\solution{generalized sorting}`{=latex}: \
  $\longrightarrow~~$ Super-fast solvers on **simple domains** (esp. 2D/3D spaces).\
  $\longrightarrow~~$ Simple registration for shapes that are close to each other. \
  $\longrightarrow~~$ **Fundamental tool** at the intersection of geometry and statistics. \
  $\longrightarrow~~$ Can we extend recent computational advances to **topology-aware** metrics? \
  \
  
- GPUs are more **versatile** than you think. \
  $\longrightarrow~~$ Ongoing work to provide **fast GPU backends** to researchers, \
  $\phantom{\longrightarrow}~~~$ going beyond what Google and Facebook are ready to pay for. \



## Documentation and tutorials are available online

```{=latex}
\begin{center}
$\Longrightarrow$\qquad \url{www.kernel-operations.io}\qquad $\Longleftarrow$
\vspace*{.15cm}

\includegraphics[width=.5\linewidth,frame]{images/geometric_data_analysis.png}

%\vspace*{.15cm}

\url{www.jeanfeydy.com/geometric_data_analysis.pdf}
\end{center}

```



# References


